==> yt-2.0.tar.gz: yt-2.0/yt/visualization/volume_rendering/api.py <==
"""
API for yt.visualization.volume_rendering

Author: Matthew Turk <matthewturk@gmail.com>
Affiliation: UCSD
Author: J.S. Oishi <jsoishi@gmail.com>
Affiliation: KIPAC/SLAC/Stanford
Author: Britton Smith <brittonsmith@gmail.com>
Affiliation: MSU
Homepage: http://yt.enzotools.org/
License:
  Copyright (C) 2010 Matthew Turk.  All Rights Reserved.

  This file is part of yt.

  yt is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""

from transfer_functions import TransferFunction, ColorTransferFunction, \
                             PlanckTransferFunction, \
                             MultiVariateTransferFunction, \
                             ProjectionTransferFunction
from yt.utilities.amr_utils import PartitionedGrid, VectorPlane, \
    TransferFunctionProxy
from grid_partitioner import HomogenizedVolume, \
                             HomogenizedBrickCollection, \
                             export_partitioned_grids, \
                             import_partitioned_grids
from image_handling import export_rgba, import_rgba, \
                           plot_channel, plot_rgb
from software_sampler import VolumeRendering
from camera import Camera, PerspectiveCamera, StereoPairCamera

==> yt-2.2.tar.gz: yt-2.2/yt/visualization/volume_rendering/api.py <==
"""
API for yt.visualization.volume_rendering

Author: Matthew Turk <matthewturk@gmail.com>
Affiliation: UCSD
Author: J.S. Oishi <jsoishi@gmail.com>
Affiliation: KIPAC/SLAC/Stanford
Author: Britton Smith <brittonsmith@gmail.com>
Affiliation: MSU
Homepage: http://yt-project.org/
License:
  Copyright (C) 2010-2011 Matthew Turk.  All Rights Reserved.

  This file is part of yt.

  yt is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""

from transfer_functions import TransferFunction, ColorTransferFunction, \
                             PlanckTransferFunction, \
                             MultiVariateTransferFunction, \
                             ProjectionTransferFunction
from yt.utilities.amr_utils import PartitionedGrid, VectorPlane, \
    TransferFunctionProxy
from grid_partitioner import HomogenizedVolume, \
                             HomogenizedBrickCollection, \
                             export_partitioned_grids, \
                             import_partitioned_grids
from image_handling import export_rgba, import_rgba, \
                           plot_channel, plot_rgb
from software_sampler import VolumeRendering
from camera import Camera, PerspectiveCamera, StereoPairCamera
